@@ -82,13 +82,13 @@
 #' gev_loglik <- function(pars, data) {
 #'   o_pars <- pars[c(1, 3, 5)] + pars[c(2, 4, 6)]
 #'   w_pars <- pars[c(1, 3, 5)] - pars[c(2, 4, 6)]
-#'   if (o_pars[2] <= 0 | w_pars[2] <= 0) return(-Inf)
+#'   if (isTRUE(o_pars[2] <= 0 | w_pars[2] <= 0)) return(-Inf)
 #'   o_data <- data[, "Oxford"]
 #'   w_data <- data[, "Worthing"]
 #'   check <- 1 + o_pars[3] * (o_data - o_pars[1]) / o_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   check <- 1 + w_pars[3] * (w_data - w_pars[1]) / w_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   o_loglik <- log_gev(o_data, o_pars[1], o_pars[2], o_pars[3])
 #'   w_loglik <- log_gev(w_data, w_pars[1], w_pars[2], w_pars[3])
 #'   return(o_loglik + w_loglik)
@@ -104,7 +104,7 @@
 #' large <- adjust_loglik(gev_loglik, data = owtemps, init = init,
 #'                        par_names = par_names)
 #'
-#' \dontrun{
+#' \donttest{
 #' # Plots like those in Figure 4 of Chandler and Bate (2007)
 #' # (a)
 #' which_pars <- c("mu[0]", "mu[1]")
@@ -298,7 +298,7 @@ conf_region <- function(object, which_pars = NULL, range1 = c(NA, NA),
                           prof_vals = prof_vals, init = theta, type = type),
                      optim_args)
       zz <- try(do.call(profile_loglik, prof_args), silent = TRUE)
-      if (class(zz) == "try-error") {
+      if (inherits(zz, "try-error")) {
         z[i, j] <- NA
       } else {
         z[i, j] <- zz
@@ -426,13 +426,13 @@ conf_region <- function(object, which_pars = NULL, range1 = c(NA, NA),
 #' gev_loglik <- function(pars, data) {
 #'   o_pars <- pars[c(1, 3, 5)] + pars[c(2, 4, 6)]
 #'   w_pars <- pars[c(1, 3, 5)] - pars[c(2, 4, 6)]
-#'   if (o_pars[2] <= 0 | w_pars[2] <= 0) return(-Inf)
+#'   if (isTRUE(o_pars[2] <= 0 | w_pars[2] <= 0)) return(-Inf)
 #'   o_data <- data[, "Oxford"]
 #'   w_data <- data[, "Worthing"]
 #'   check <- 1 + o_pars[3] * (o_data - o_pars[1]) / o_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   check <- 1 + w_pars[3] * (w_data - w_pars[1]) / w_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   o_loglik <- log_gev(o_data, o_pars[1], o_pars[2], o_pars[3])
 #'   w_loglik <- log_gev(w_data, w_pars[1], w_pars[2], w_pars[3])
 #'   return(o_loglik + w_loglik)
@@ -453,7 +453,7 @@ conf_region <- function(object, which_pars = NULL, range1 = c(NA, NA),
 #' large_v
 #' plot(large_v)
 #' plot(large_v, which_par = "xi[1]")
-#' \dontrun{
+#' \donttest{
 #' # Unadjusted
 #' large_none <- conf_intervals(large, which_pars = c("xi[0]", "xi[1]"),
 #'                              type = "none")
@@ -680,13 +680,13 @@ conf_intervals <- function(object, which_pars = NULL, init = NULL, conf = 95,
 #' gev_loglik <- function(pars, data) {
 #'   o_pars <- pars[c(1, 3, 5)] + pars[c(2, 4, 6)]
 #'   w_pars <- pars[c(1, 3, 5)] - pars[c(2, 4, 6)]
-#'   if (o_pars[2] <= 0 | w_pars[2] <= 0) return(-Inf)
+#'   if (isTRUE(o_pars[2] <= 0 | w_pars[2] <= 0)) return(-Inf)
 #'   o_data <- data[, "Oxford"]
 #'   w_data <- data[, "Worthing"]
 #'   check <- 1 + o_pars[3] * (o_data - o_pars[1]) / o_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   check <- 1 + w_pars[3] * (w_data - w_pars[1]) / w_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   o_loglik <- log_gev(o_data, o_pars[1], o_pars[2], o_pars[3])
 #'   w_loglik <- log_gev(w_data, w_pars[1], w_pars[2], w_pars[3])
 #'   return(o_loglik + w_loglik)
@@ -847,13 +847,13 @@ profile_loglik <- function(object, prof_pars = NULL, prof_vals = NULL,
 #' gev_loglik <- function(pars, data) {
 #'   o_pars <- pars[c(1, 3, 5)] + pars[c(2, 4, 6)]
 #'   w_pars <- pars[c(1, 3, 5)] - pars[c(2, 4, 6)]
-#'   if (o_pars[2] <= 0 | w_pars[2] <= 0) return(-Inf)
+#'   if (isTRUE(o_pars[2] <= 0 | w_pars[2] <= 0)) return(-Inf)
 #'   o_data <- data[, "Oxford"]
 #'   w_data <- data[, "Worthing"]
 #'   check <- 1 + o_pars[3] * (o_data - o_pars[1]) / o_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   check <- 1 + w_pars[3] * (w_data - w_pars[1]) / w_pars[2]
-#'   if (any(check <= 0)) return(-Inf)
+#'   if (isTRUE(any(check <= 0))) return(-Inf)
 #'   o_loglik <- log_gev(o_data, o_pars[1], o_pars[2], o_pars[3])
 #'   w_loglik <- log_gev(w_data, w_pars[1], w_pars[2], w_pars[3])
 #'   return(o_loglik + w_loglik)
